<?php
/*
********************************************************************************
 ADVANCED NEWS plugin for CMSimple
 ------------------------------------
 Author  :  Jan Kanters - jan.kanters@telenet.be 
 Date    :  14/09/2007 (dd/mm/yyyy)
 Version :  V 1.0.5
 Credits :  - flatfile database class Copyright (c) 2005 Luke Plant <L.Plant.98@cantab.net>
            - HTMLArea / FCKEditor / Tiny MCE / Xinha WYSIWYG editor by their respective Copyright holders
            - Date Picker (jscalendar) by Copyright (c) Dynarch.com
 License : GNU General Public License, version 2 or later of your choice
********************************************************************************
Copyright (C) 2006-2010 Jan Kanters

This program is free software; you can redistribute it and/or modify it under the terms of the 
GNU General Public License as published by the Free Software Foundation; either version 2 of the 
License.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; 
if not, see <http://www.gnu.org/licenses>.
*/

/*
********************************************************************************
* This routine does some automatic news status updating
* it changes the news status automatically from :
*   - ready to publish -> published; when current date is in between start & end date
*   - published -> archived; when current date > end date
* and also generates an up-to-date RSS newsfeed file
********************************************************************************
*/

define('ADV_NEWS_VERSION', "V 1.0.5 (2010.09.06)");
if (!$adm)
    {
    // recover variables from outsite the function
    global $pth, $sn, $plugin_tx, $plugin_cf, $u, $s, $c, $sl, $f, $tx, $cal_format, $hjs;
    // create the site RSS:rdf file
    export_rssfeed();
    // get plugin name
    $plugin=basename(dirname(__FILE__), "/");
    // set locale time
    setlocale(LC_ALL, $plugin_tx[$plugin]['news_date_locale']);
    // set general variables for the plugin
    $plugin_images_folder =$pth['folder']['plugins'] . $plugin . "/images/";
    $plugin_include_folder=$pth['folder']['plugins'] . $plugin . "/include/";
    $db_path              =$pth['folder']['plugins'] . $plugin . "/data/";
    $db_name              ="news-" . $sl . ".txt";
    // include the flatfile database class
    require_once ($plugin_include_folder . "flatfile.php");
    // declare the news database fields
    require_once ($plugin_include_folder . "fields.php");
    // connect to the news database file
    $db                   =new Flatfile();
    $db->datadir          =$db_path;
    $d                    =date("d", time());
    $m                    =date("n", time());
    $y                    =date("Y", time());
    $today                =mktime(NULL, NULL, NULL, $m, $d, $y);
    // Change news status from ready for publishing to published when current date is within the publishing period
    $compClause           =NULL;

    if (strtolower($plugin_cf[$plugin]['news_auto_publish_status']) == 'true'
        || strtolower($plugin_cf[$plugin]['news_auto_publish_status']) == '1')
        {
        $compClause
                =new AndWhereClause(new SimpleWhereClause(NEWS_STATUS, "<=", 0, INTEGER_COMPARISON),
                                    new AndWhereClause(new SimpleWhereClause(NEWS_STARTDATE, "<=", $today),
                                                       new SimpleWhereClause(NEWS_ENDDATE, ">=", $today)));
        $records=$db->selectWhere($db_name, $compClause, -1);

        foreach ($records as $key => $field)
            {
            unset ($newsitem);
            $newsitem[NEWS_ID]    =$field[NEWS_ID];
            $newsitem[NEWS_STATUS]=1;
            $db->updateRowById($db_name, NEWS_ID, $newsitem);
            }
        }

    // Change news status from published to archived when publishing period is ended
    $compClause=NULL;
    $compClause=new AndWhereClause(new SimpleWhereClause(NEWS_STATUS, "<=", 1),
                                   new SimpleWhereClause(NEWS_ENDDATE, "<", $today, INTEGER_COMPARISON));
    $records   =$db->selectWhere($db_name, $compClause, -1, array
                (
                new OrderBy(NEWS_DATE, DESCENDING, INTEGER_COMPARISON),
                new OrderBy(NEWS_ID, DESCENDING, INTEGER_COMPARISON)
                ));

    foreach ($records as $key => $field)
        {
        unset ($newsitem);
        $newsitem[NEWS_ID]    =$field[NEWS_ID];
        $newsitem[NEWS_STATUS]=2;
        $db->updateRowById($db_name, NEWS_ID, $newsitem);
      }
    $hjs .="<link rel='alternate' type='application/rss+xml' title='".sitename()."' href='".$pth['folder']['plugins'].$plugin."/rss/newsfeed-".$sl.".xml' />";
    }

/*
********************************************************************************
* This function display's the archived news topics
* parameters :
*     - layout [optional] : either table or advanced
*                           default='table'
*     - displaysearch [optional] : true/false ; sets the search options on or off
*                                  default='off'
* usage : shownewsarchive('default=advanced,displaysearch=true')
********************************************************************************
*/
function shownewsarchive ($options = NULL)
    {
    // recover variables from outsite the function
    global $pth, $sn, $plugin_tx, $plugin_cf, $u, $s, $c, $sl, $f, $tx, $cal_format, $hjs;
    // get plugin name
    $plugin=basename(dirname(__FILE__), "/");
    // set locale time
    setlocale(LC_ALL, $plugin_tx[$plugin]['news_date_locale']);
    $layout       ='table';
    $includesearch='false';
    $arguments    =split(",", $options);

    if (count($arguments > 0))
        {
        foreach ($arguments as $argument)
            {
            $property = split("=", $argument);

            switch (strtolower($property[0]))
                {
                case "layout":
                    $layout=(strtolower($property[1]) == 'table' || strtolower($property[1]) == 'advanced')
                        ? strtolower($property[1]) : 'table';

                    break;

                case "displaysearch":
                    if (strtolower($property[1]) === "true" || strtolower($property[1]) === "false"
                        || strtolower($property[1]) === "1" || strtolower($property[1]) === "0")
                        {
                        switch ($property[1])
                            {
                            case '0':
                                $includesearch='false';

                                break;

                            case '1':
                                $includesearch='true';

                                break;

                            default:
                                $includesearch=strtolower($property[1]);

                                break;
                            }
                        }
                    else { $includesearch='false'; }

                    break;
                }
            }
        }

    // retrieve posted variables
    $newsID    =isset($_POST['newsID']) ? $_POST['newsID'] : $_GET['newsID'];
    $page      =isset($_POST['page']) ? $_POST['page'] : $_GET['page'];
    $newsaction=isset($_POST['newsaction']) ? $_POST['newsaction'] : $_GET['newsaction'];
    $newsYear  =isset($_POST['newsYear']) ? $_POST['newsYear'] : $_GET['newsYear'];
    $compClause=isset($_POST['compClause']) ? $_POST['compClause'] : $_GET['compClause'];
    $printnews =isset($_POST['printnews']) ? $_POST['printnews'] : $_GET['printnews'];
    // Date Picker settings
    $monthnames=explode(",", $plugin_tx[$plugin]['news_month_names']);

    foreach ($monthnames as $key => $value) { $months=$months . '"' . $value . '",'; }

    $months=substr($months, 0, strlen($months) - 1);
    $daynames1=explode(",", $plugin_tx[$plugin]['news_weekday_names1']);

    foreach ($daynames1 as $key => $value) { $days1=$days1 . '"' . $value . '",'; }

    $days1=substr($days1, 0, strlen($days1) - 1);
    $daynames2=explode(",", $plugin_tx[$plugin]['news_weekday_names2']);

    foreach ($daynames2 as $key => $value) { $days2=$days2 . '"' . $value . '",'; }

    $days2=substr($days2, 0, strlen($days2) - 1);
    // Calendar plugin
    $hjs.="<link rel=\"stylesheet\" type=\"text/css\" media=\"all\" href=\"" . $pth['folder']['plugins'] . $plugin
        . "/jscalendar/calendar-system.css\" />";
    $hjs.='<script type="text/javascript" src="' . $pth['folder']['plugins'] . $plugin
        . '/jscalendar/calendar.js"></script>';
    // Set jscalendar to default (en) if current website language isn't available
    $hjs.=(is_file($pth['folder']['plugins'] . $plugin . "/jscalendar/lang/calendar-" . $sl . ".js"))
        ? '<script type="text/javascript" src="' . $pth['folder']['plugins'] . $plugin . '/jscalendar/lang/calendar-'
        . $sl . '.js"></script>'
        : '<script type="text/javascript" src="' . $pth['folder']['plugins'] . $plugin . '/jscalendar/lang/calendar-en.js"></script>';
    // End modify JAT 07/11/2005
    $hjs.='<script type="text/javascript" src="' . $pth['folder']['plugins'] . $plugin
        . '/jscalendar/calendar-setup.js"></script>';
    // End added JAT 29/10/2005 //
    // set general variables for the plugin
    $plugin_images_folder=$pth['folder']['plugins'] . $plugin . "/images/";
    $plugin_include_folder=$pth['folder']['plugins'] . $plugin . "/include/";
    $db_path=$pth['folder']['plugins'] . $plugin . "/data/";
    $db_name="news-" . $sl . ".txt";
    // Show / hide search block
    $hjs.='<script type="text/javascript">
        function showSearch() {
             if (document.getElementById("searchblock").style.display == "none"){
                var mytitle="'
        . $plugin_tx[$plugin]['news_tooltip_hidesearch'] . '";
                document.getElementById("btn_img").title=mytitle;
                document.getElementById("btn_img").src="' . $plugin_images_folder . 'btn_collapse.gif";
        		document.getElementById("searchblock").style.display = "block";
        	}else{
                var mytitle="' . $plugin_tx[$plugin]['news_tooltip_showsearch'] . '";
                document.getElementById("btn_img").title=mytitle;
                document.getElementById("btn_img").src="' . $plugin_images_folder . 'btn_expand.gif";
                document.getElementById("searchblock").style.display = "none";
            }
        }
        </script>';
    // include the flatfile database class
    require_once ($plugin_include_folder . "flatfile.php");
    // declare the news database fields
    require_once ($plugin_include_folder . "fields.php");
    // connect to the news database file
    $db         =new Flatfile();
    $db->datadir=$db_path;

    if ($newsaction != "view")
        {
        $compClause     =new SimpleWhereClause(NEWS_STATUS, '=', 2, INTEGER_COMPARISON);
        global $pth, $sn, $plugin_tx, $plugin_cf, $u, $s, $c, $sl, $f, $tx;
        // Create the appropriate date format for the date picker
        $my_date_format1=split('[/]', $plugin_tx[$plugin]['news_date_format']);

        if (count($my_date_format1) > 1) { $date_separator1="/"; }
        else
            {
            $my_date_format1=split('[.]', $plugin_tx[$plugin]['news_date_format']);

            if (count($my_date_format1) > 1) { $date_separator1="."; }
            else
                {
                $my_date_format1=split('[-]', $plugin_tx[$plugin]['news_date_format']);

                if (count($my_date_format1) > 1) { $date_separator1="-"; }
                }
            }

        for ($aCounter1=0; $aCounter1 <= 2; $aCounter1++)
            {
            switch ($my_date_format1[$aCounter1])
                {
                case 'd':
                    $cal_date_format1[$aCounter1]="%d";

                    break;

                case 'm':
                    $cal_date_format1[$aCounter1]="%m";

                    break;

                case 'y':
                    $cal_date_format1[$aCounter1]="%y";

                    break;

                case 'Y':
                    $cal_date_format1[$aCounter1]="%Y";

                    break;
                }
            }

        foreach ($cal_date_format1 as $key
        => $value) { $cal_format.=($key < count($my_date_format1) - 1) ? $value . $date_separator1 : $value; }

        // Build the search block
        if (strtolower($includesearch) == 'true')
            {
            $t.="<div><form name=\"newssearch\" method=\"post\" action=\"" . $sn . "?" . $u[$s] . "\">";
            $t
                .="<div id=\"enablesearch\"><a href=\"javascript:showSearch()\"><img id=\"btn_img\" alt=\"searchbuttonimg\" src=\"" . $plugin_images_folder . "btn_expand.gif" . "\" title=\"" . $plugin_tx[$plugin]['news_tooltip_showsearch'] . "\" align=\"middle\" border=\"none\"></img></a>&nbsp;" . $tx['search']['button'] . "</div>";
            $t.="<div id=\"searchblock\" style=\"display:none\">";
            $t.="<input type=\"hidden\" name=\"newsaction\" value=\"search\" />";
            $t.="<input type=\"hidden\" name=\"newsYear\" value=\"" . $newsYear . "\" />";
            $t.="<table width=\"100%\">";
            $t.="<tr><td valign=\"top\" width=\"30%\">" . $plugin_tx[$plugin]['news_date_label']
                . "</td><td><select name=\"date_operator_1\"><option value=\"=\">=</option><option value=\">\">></option><option value=\">=\" selected=\"selected\">>=</option><option value=\"&lt;\"></option><option value=\"&lt;=\">&lt;=</option></select>";
            // Start modified [JAT] 30/10/2005 //
            $t.="<input type=\"text\" id=\"date1\" name=\"news_from_date\" value=\"" . $news_from_date
                . "\" size=\"10\" maxlength=\"10\" readonly=\"readonly\" onfocus=\"this.blur()\" />&nbsp;<img src=\"" . $plugin_images_folder . "btn_calendar.gif\" alt=\"calendar_img\" align=\"middle\" border=\"0\" id=\"trig_date1\" title=\"" . $plugin_tx[$plugin]['news_tooltip_datepicker'] . "\"></img>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<select name=\"date_operator_2\"><option value=\">\">></option><option value=\">=\">>=</option><option value=\"&lt;\">&lt;</option><option value=\"&lt;=\"  selected=\"selected\">&lt;=</option></select><input type=\"text\" id=\"date2\" name=\"news_to_date\" value=\"" . $news_to_date . "\" size=\"10\" maxlength=\"10\" readonly=\"readonly\" />&nbsp;<img src=\"" . $plugin_images_folder . "btn_calendar.gif\" alt=\"calendar_img\" align=\"middle\" border=\"0\" id=\"trig_date2\" title=\"" . $plugin_tx[$plugin]['news_tooltip_datepicker'] . "\"></img>";
            // End modified [JAT] 30/10/2005 //
            // Start added [JAT] 30/10/2005 //
            $t.="<script type=\"text/javascript\">Calendar.setup({inputField : \"date1\",ifFormat : \"" . $cal_format
                . "\",button : \"trig_date1\",align : \"Br\",singleClick : false,firstDay: 1,weekNumbers : false,electric:false,showsTime:false,timeFormat: \"24\",step: \"1\"});Calendar.setup({inputField : \"date2\",ifFormat : \"" . $cal_format . "\",button : \"trig_date2\",align : \"Br\",singleClick : false,firstDay: 1,weekNumbers : false,electric:false,showsTime:false,timeFormat: \"24\",step: \"1\"});</script></td></tr>";
            // End added [JAT] 30/10/2005 //
            $t
                .="<tr><td valign=\"top\" width=\"30%\">&nbsp;</td><td><input id=\"operator_1a\" type=\"radio\" name=\"operator_1\" value=\"AND\" checked=\"checked\" />" . $plugin_tx[$plugin]['news_search_and'] . "&nbsp;&nbsp;&nbsp;<input id=\"operator_1b\" type=\"radio\" name=\"operator_1\" value=\"OR\" />" . $plugin_tx[$plugin]['news_search_or'] . "</td></tr>";
            $t.="<tr><td valign=\"top\" width=\"30%\">" . $plugin_tx[$plugin]['news_title_label']
                . "</td><td><select name=\"title_operator\"><option value=\"1\">" . $plugin_tx[$plugin]['news_search_startswith'] . "</option><option value=\"2\" selected=\"selected\">" . $plugin_tx[$plugin]['news_search_contains'] . "</option><option value=\"3\">" . $plugin_tx[$plugin]['news_search_endswith'] . "</option></select><input type=\"text\" name=\"news_title\" size=\"35\" maxlength=\"64\" /></td></tr>";
            $t
                .="<tr><td valign=\"top\" width=\"30%\">&nbsp;</td><td><input id=\"operator_2a\" type=\"radio\" name=\"operator_2\" value=\"AND\" checked=\"checked\" />" . $plugin_tx[$plugin]['news_search_and'] . "&nbsp;&nbsp;&nbsp;<input id=\"operator_2b\" type=\"radio\" name=\"operator_2\" value=\"OR\" />" . $plugin_tx[$plugin]['news_search_or'] . "</td></tr>";
            $t.="<tr><td valign=\"top\" width=\"30%\">" . $plugin_tx[$plugin]['news_story_label']
                . "</td><td><select name=\"story_operator\"><option value=\"1\">" . $plugin_tx[$plugin]['news_search_startswith'] . "</option><option value=\"2\" selected=\"selected\">" . $plugin_tx[$plugin]['news_search_contains'] . "</option><option value=\"3\">" . $plugin_tx[$plugin]['news_search_endswith'] . "</option></select><input type=\"text\" name=\"news_story\" size=\"35\" maxlength=\"64\" /></td></tr>";
            $t.="<tr><td>&nbsp;</td></tr>";
            $t.="<tr><td colspan=\"2\" align=\"center\"><input type=\"submit\" name=\"send\" value=\""
                . $tx['search']['button'] . "\"/></td></tr>";
            $t.="</table></div>";
            $t.="</form>";
            $t.="</div>";
            }

        if ($newsaction == "search")
            {
            $compArchiveClause=new SimpleWhereClause(NEWS_STATUS, '=', 2, INTEGER_COMPARISON);

            if (!empty($_REQUEST[news_from_date])) { $compClauseDate1
                =new SimpleWhereClause(NEWS_DATE, $_REQUEST[date_operator_1],
                                           make_timestamp_date1($_REQUEST[news_from_date])); }

            if (!empty($_REQUEST[news_to_date])) { $compClauseDate2
                =new SimpleWhereClause(NEWS_DATE, $_REQUEST[date_operator_2],
                                           make_timestamp_date1($_REQUEST[news_to_date])); }

            if (!empty($_REQUEST[news_title])) { $compClauseTitle
                =new LikeWhereClause(NEWS_TITLE, $_REQUEST[news_title], $_REQUEST[title_operator]); }

            if (!empty($_REQUEST[news_story])) { $compClauseStory
                =new LikeWhereClause(NEWS_STORY, $_REQUEST[news_story], $_REQUEST[story_operator]); }

            // [only from_date]
            if (!empty($compClauseDate1) && empty($compClauseDate2) && empty($compClauseTitle)
                    && empty($compClauseStory)) { $compClause=$compClauseDate1; }

            // [only to_date]
            if (empty($compClauseDate1)
                && !empty($compClauseDate2) && empty($compClauseTitle) && empty($compClauseStory))
                { $compClause=$compClauseDate2; }

            // [from_date & to_date]
            if (!empty($compClauseDate1)
                    && !empty($compClauseDate2) && empty($compClauseTitle) && empty($compClauseStory)) { $compClause
                =new AndWhereClause($compClauseDate1, $compClauseDate2); }

            // [only title]
            if (empty($compClauseDate1) && empty($compClauseDate2)
                && !empty($compClauseTitle) && empty($compClauseStory)) { $compClause=$compClauseTitle; }

            // [from_date & title]
            if (!empty($compClauseDate1) && empty($compClauseDate2)
                    && !empty($compClauseTitle) && empty($compClauseStory))
                {
                switch ($_REQUEST[operator_1])
                    {
                    case "AND":
                        $compClause=new AndWhereClause($compClauseDate1, $compClauseTitle);

                        break;

                    case "OR":
                        $compClause=new OrWhereClause($compClauseDate1, $compClauseTitle);

                        break;
                    }
                }

            // [to_date & title]
            if (empty($compClauseDate1)
                && !empty($compClauseDate2) && !empty($compClauseTitle) && empty($compClauseStory))
                {
                switch ($_REQUEST[operator_1])
                    {
                    case "AND":
                        $compClause=new AndWhereClause($compClauseDate2, $compClauseTitle);

                        break;

                    case "OR":
                        $compClause=new OrWhereClause($compClauseDate2, $compClauseTitle);

                        break;
                    }
                }

            // [from_date, to_date & title]
            if (!empty($compClauseDate1)
                    && !empty($compClauseDate2) && !empty($compClauseTitle) && empty($compClauseStory))
                {
                switch ($_REQUEST[operator_1])
                    {
                    case "AND":
                        $compClause
                        =new AndWhereClause(new AndWhereClause($compClauseDate1, $compClauseDate2), $compClauseTitle);

                        break;

                    case "OR":
                        $compClause
                        =new OrWhereClause(new AndWhereClause($compClauseDate1, $compClauseDate2), $compClauseTitle);

                        break;
                    }
                }

            // [only story]
            if (empty($compClauseDate1) && empty($compClauseDate2) && empty($compClauseTitle)
                && !empty($compClauseStory)) { $compClause=$compClauseStory; }

            // [from_date & story]
            if (!empty($compClauseDate1) && empty($compClauseDate2) && empty($compClauseTitle)
                    && !empty($compClauseStory))
                {
                switch ($_REQUEST[operator_2])
                    {
                    case "AND":
                        $compClause=new AndWhereClause($compClauseDate1, $compClauseStory);

                        break;

                    case "OR":
                        $compClause=new OrWhereClause($compClauseDate1, $compClauseStory);

                        break;
                    }
                }

            // [to_date & story]
            if (empty($compClauseDate1)
                && !empty($compClauseDate2) && empty($compClauseTitle) && !empty($compClauseStory))
                {
                switch ($_REQUEST[operator_2])
                    {
                    case "AND":
                        $compClause=new AndWhereClause($compClauseDate2, $compClauseStory);

                        break;

                    case "OR":
                        $compClause=new OrWhereClause($compClauseDate2, $compClauseStory);

                        break;
                    }
                }

            // [from_date, to_date & story]
            if (!empty($compClauseDate1)
                    && !empty($compClauseDate2) && empty($compClauseTitle) && !empty($compClauseStory))
                {
                switch ($_REQUEST[operator_2])
                    {
                    case "AND":
                        $compClause
                        =new AndWhereClause(new AndWhereClause($compClauseDate1, $compClauseDate2), $compClauseStory);

                        break;

                    case "OR":
                        $compClause
                        =new OrWhereClause(new AndWhereClause($compClauseDate1, $compClauseDate2), $compClauseStory);

                        break;
                    }
                }

            // [title & story]
            if (empty($compClauseDate1) && empty($compClauseDate2)
                && !empty($compClauseTitle) && !empty($compClauseStory))
                {
                switch ($_REQUEST[operator_2])
                    {
                    case "AND":
                        $compClause=new AndWhereClause($compClauseTitle, $compClauseStory);

                        break;

                    case "OR":
                        $compClause=new OrWhereClause($compClauseTitle, $compClauseStory);

                        break;
                    }
                }

            // [from_date, title & story specified
            if (!empty($compClauseDate1) && empty($compClauseDate2)
                    && !empty($compClauseTitle) && !empty($compClauseStory))
                {
                $compClause=$compClauseDate1;

                switch ($_REQUEST[operator_1])
                    {
                    case "AND":
                        $compClause=new AndWhereClause($compClause, $compClauseTitle);

                        break;

                    case "OR":
                        $compClause=new OrWhereClause($compClause, $compClauseTitle);

                        break;
                    }

                switch ($_REQUEST[operator_2])
                    {
                    case "AND":
                        $compClause=new AndWhereClause($compClause, $compClauseStory);

                        break;

                    case "OR":
                        $compClause=new OrWhereClause($compClause, $compClauseStory);

                        break;
                    }
                }

            // [to_date, title & story]
            if (empty($compClauseDate1)
                && !empty($compClauseDate2) && !empty($compClauseTitle) && !empty($compClauseStory))
                {
                $compClause=$compClauseDate2;

                switch ($_REQUEST[operator_1])
                    {
                    case "AND":
                        $compClause=new AndWhereClause($compClause, $compClauseTitle);

                        break;

                    case "OR":
                        $compClause=new OrWhereClause($compClause, $compClauseTitle);

                        break;
                    }

                switch ($_REQUEST[operator_2])
                    {
                    case "AND":
                        $compClause=new AndWhereClause($compClause, $compClauseStory);

                        break;

                    case "OR":
                        $compClause=new OrWhereClause($compClause, $compClauseStory);

                        break;
                    }
                }

            // [from_date, to_date, title & story]
            if (!empty($compClauseDate1)
                    && !empty($compClauseDate2) && !empty($compClauseTitle) && !empty($compClauseStory))
                {
                $compClause=new AndWhereClause($compClauseDate1, $compClauseDate2);

                switch ($_REQUEST[operator_1])
                    {
                    case "AND":
                        $compClause=new AndWhereClause($compClause, $compClauseTitle);

                        break;

                    case "OR":
                        $compClause=new OrWhereClause($compClause, $compClauseTitle);

                        break;
                    }

                switch ($_REQUEST[operator_2])
                    {
                    case "AND":
                        $compClause=new AndWhereClause($compClause, $compClauseStory);

                        break;

                    case "OR":
                        $compClause=new OrWhereClause($compClause, $compClauseStory);

                        break;
                    }
                }
            }

        if ($newsaction == "search")
            {
            $compClause=serialize($compClause);
            session_write_close();

            if (isset($compClause)) { $compClause=new AndWhereClause($compArchiveClause, $compClause); }
            else { unset ($newsaction); }

            $records
            =$db->selectWhere($db_name, $compClause, -1, array
                (
                new OrderBy(NEWS_DATE, DESCENDING, INTEGER_COMPARISON),
                new OrderBy(NEWS_ID, DESCENDING, INTEGER_COMPARISON)
                ));
            }
        else
            {
            // Select all news items from the DB
            if (isset($compClause)) { $compClause=unserialize($compClause); }

            if (empty($compClause)) { $compClause=$compArchiveClause; }

            $records
            =$db->selectWhere($db_name, $compClause, -1,array
                (
                new OrderBy(NEWS_DATE, DESCENDING, INTEGER_COMPARISON),
                new OrderBy(NEWS_ID, DESCENDING, INTEGER_COMPARISON)
                ));
            }

        switch (strtolower($layout))
            {
            case "table":
                // Set limit of record in the table
                $page_record_limit=$plugin_cf[$plugin]['news_archive_records_page'];

                if ($page_record_limit <= 0) { $page_record_limit=10; }

                if ($page_record_limit >= 32) { $page_record_limit=32; }

                // Count the total records
                $db_total_records=count($records);
                // Calculate the number of possible pages
                $page_total      =($db_total_records % $page_record_limit == 0)
                    ? ((int)$db_total_records / $page_record_limit)
                    : ((int)($db_total_records / $page_record_limit) + 1);
                // Calculate table paging
                $t.="<div class=\"show_news_box\">";

                // $t.="<div><h4>".strtoupper($plugin_tx[$plugin]['news_story_overview'])."</h4></div>";
                if ($page > $page_total) { $page=1; }

                if ($page == "" || $page <= 0 || $page == 1)
                    {
                    $start_index=0;
                    $page       =1;
                    }
                else { $start_index=(($page - 1) * ($page_record_limit)); }

                // Display news items overview
                $t.="<div>&nbsp;</div>";
                // Display table header
                $t.="<div><table class=\"news_table\" width=\"100%\" cellpadding=\"0\" cellspacing=\"0\">";
                //$t.="<tr><td class=\"news_table_header\" align=\"center\"width=\"20%\">".$plugin_tx[$plugin]['news_date_label']."</td>";
                //$t.="<td class=\"news_table_header\">".$plugin_tx[$plugin]['news_title_label']."</td></tr></table></div>";
                $t.="<tr><td><table border=\"0\" width=\"100%\" cellpadding=\"0\" cellspacing=\"0\">";
                $end_index=$page * $page_record_limit - 1;

                // Display table lines
                for ($record_index=$start_index; $record_index <= $end_index; $record_index++)
                    {
                    //$color = $record_index % 2 ? "#cccccc" : "#99cccc";
                    if ($record_index > $db_total_records - 1) { $t
                        .="<tr><td class=\"news_table_line\" align=\"center\" width=\"20%\">&nbsp;</td><td class=\"news_table_line\">&nbsp;</td></tr>";
                        }
                    else
                        {
                        $field=$records[$record_index];
                        $t.="<tr><td bgcolor=\"" . $color
                            . "\" align=\"center\" class=\"news_table_line\" width=\"20%\">"
                            . date($plugin_tx[$plugin]['news_date_format'], $field[NEWS_DATE])
                            . "</td><td bgcolor=\"" . $color . "\" class=\"news_table_line\"><a href=\"" . $sn . "?" . $u[$s] . "&amp;newsaction=view&amp;newsID=" . $field[NEWS_ID] . "&amp;page=" . $page . "\" title=\"" . $plugin_tx[$plugin]["news_tooltip_view"] . "\" >" . $field[NEWS_TITLE] . "</a></td></tr>";
                        }
                    }

                $t.="</table></td></tr></table></div>";
                $tmp=($db_total_records > 0)
                    ? "" . $plugin_tx[$plugin]['news_page_label'] . " : " . $page . " / " . $page_total : "";
                // News overview paging
                $t.="<div class=\"paging_block\"><div class=\"db_info\">" . $plugin_tx[$plugin]['news_record_count']
                    . " : " . $db_total_records . "</div></div><div class=\"page_info\">&nbsp;&nbsp;&nbsp;" . $tmp . "</div>";
                $mysearch="";

                if ($db_total_records > 0 && $page_total > 1)
                    {
                    if ($page_total > $page)
                        {
                        $next=$page + 1;
                        $back=($page > 1) ? ($next - 2) : "1";
                        }
                    else
                        {
                        $next=$page_total;
                        $back=$page_total - 1;
                        }

                    $t.="<div class=\"table_paging\"><a href=\"" . $sn . "?" . $u[$s] . "&amp;page=" . $back . $mysearch
                        . "\" title=\"" . $plugin_tx[$plugin]['news_tooltip_previous'] . "\"><img src=\"" . $plugin_images_folder . "btn_previous.gif\" alt=\"previous_img\"></img></a>&nbsp;&nbsp;";

                    for ($tt=1; $tt <= $page_total; $tt++)
                        {
                        $separator = ($tt < $page_total) ? " " : "";
                        $t.="<a href=\"" . $sn . "?" . $u[$s] . "&amp;page=" . $tt . $mysearch . "\" title=\""
                            . $plugin_tx[$plugin]['news_page_label'] . " " . $tt . "\">[" . $tt . "]</a>" . $separator;
                        }

                    $t.="&nbsp;&nbsp;<a href=\"" . $sn . "?" . $u[$s] . "&amp;page=" . $next . $mysearch . "\" title=\""
                        . $plugin_tx[$plugin]['news_tooltip_next'] . "\"><img src=\"" . $plugin_images_folder . "btn_next.gif\" alt=\"next_img\"></img></a>";
                    $t.="</div>";
                    }

                $t.="</div>";
                break;

            case "advanced":
                $news_topics_total=count($records);

                $filter_total     =0;

                if ($newsaction != "search")
                    {
                    $currentYear=date("Y", time());

                    if (!isset($newsYear) || $newsYear <= 0 || $newsYear >= $currentYear || empty($newsYear))
                        {
                        $newsYear    =$currentYear;
                        $currentMonth=date("n", time());
                        }
                    else { $currentMonth=12; }

                    $next=($newsYear < $currentYear) ? ($newsYear + 1) : $currentYear;
                    $back=$newsYear - 1;
                    $t.="<div>&nbsp;</div>";
                    $t.="<div class=\"table_paging\"><a href=\"" . $sn . "?" . $u[$s] . "&amp;newsYear=" . $back
                        . "\" title=\"" . $plugin_tx[$plugin]['news_tooltip_previousyear'] . "\"><img src=\"" . $plugin_images_folder . "btn_previous.gif\" alt=\"previous_img\"></img></a>&nbsp;&nbsp;";
                    $t.="[ " . $plugin_tx[$plugin]['news_archive_year'] . $newsYear . " ]";
                    $t.="&nbsp;&nbsp;<a href=\"" . $sn . "?" . $u[$s] . "&amp;newsYear=" . $next . "\" title=\""
                        . $plugin_tx[$plugin]['news_tooltip_nextyear'] . "\"><img src=\"" . $plugin_images_folder . "btn_next.gif\" alt=\"next_img\"></img></a>";
                    $t.="</div>";
                    $t.="<div>&nbsp;</div>";
                    $startmonth     =mktime(NULL, NULL, NULL, 1, 1, $newsYear);
                    $endmonth       =mktime(NULL, NULL, NULL, 12, 1, $newsYear);
                    $compClause     =new AndWhereClause(
                                         new AndWhereClause(
                                             new SimpleWhereClause(NEWS_DATE, '>=', $startmonth, INTEGER_COMPARISON),
                                             new SimpleWhereClause(NEWS_DATE, '<=', $endmonth, INTEGER_COMPARISON)),
                                         new SimpleWhereClause(NEWS_STATUS, "=", 2, INTEGER_COMPARISON));
                    $generalnewslist=$db->selectWhere($db_name, $compClause, -1,
                                                     array
                (
                new OrderBy(NEWS_DATE, DESCENDING, INTEGER_COMPARISON),
                new OrderBy(NEWS_ID, DESCENDING, INTEGER_COMPARISON)
                ));

                    for ($month=$currentMonth; $month >= 1; $month--)
                        {
                        $startmonth = mktime(NULL, NULL, NULL, $month, 1, $newsYear);
                        $endmonth   =mktime(NULL, NULL, NULL, $month + 1, 1, $newsYear);
                        $compClause =new AndWhereClause(new SimpleWhereClause(NEWS_STATUS, '=', 2, INTEGER_COMPARISON),
                                                        new AndWhereClause(
                                                            new SimpleWhereClause(NEWS_DATE, '>=', $startmonth,
                                                                                  INTEGER_COMPARISON),
                                                            new SimpleWhereClause(NEWS_DATE, '<', $endmonth,
                                                                                  INTEGER_COMPARISON),
                                                            new SimpleWhereClause(NEWS_STATUS, "=", 2,
                                                                                  INTEGER_COMPARISON)));
                        $newslist   =$db->selectWhere($db_name, $compClause, -1,
                                                      array
                (
                new OrderBy(NEWS_DATE, DESCENDING, INTEGER_COMPARISON),
                new OrderBy(NEWS_ID, DESCENDING, INTEGER_COMPARISON)
                ));
                        $monthString=strftime("%B %Y", mktime(NULL, NULL, NULL, $month, 1, $newsYear));

                        if (count($newslist) > 0)
                            {
                            $t.="<b>" . $monthString . "</b><br />";
                            foreach ($newslist as $key => $field) {
                                $t.="<img src=\"" . $plugin_images_folder . "news_item.gif"
                                . "  \" alt=\"newsitem_img\"></img>&nbsp;"
                                . date($plugin_tx[$plugin]['news_date_format'],
                                       $field[NEWS_DATE]) . "&nbsp;&nbsp;&nbsp;<a href=\"" . $sn . "?" . $u[$s] . "&amp;newsaction=view&amp;newsID="
                                . $field[NEWS_ID] . "&amp;page=" . $page . "\" title=\"" . $plugin_tx[$plugin]["news_tooltip_view"]
                                . "\" >" . $field[NEWS_TITLE] . "</a><br />"; }
                            $t.="<br />";
                            }
                        }

                    if (count($generalnewslist) == 0) { $t.=$plugin_tx[$plugin]['news_no_topics']; }
                    }
                else
                    {
                    $currentMonth=12;
                    $newslist    =$records;
                    $t.="<div>&nbsp;</div>";

                    if (count($newslist) > 0)
                        {
                        foreach ($newslist as $key => $field)
                            {
                            $month      = date("n", $field[NEWS_DATE]);
                            $year       =date("Y", $field[NEWS_DATE]);
                            $monthString=strftime("%B %Y", mktime(NULL, NULL, NULL, $month, 1, $year));

                            if ($newsmonth != $month)
                                {
                                $t.=($key != 0) ? "<br />" : "";
                                $t.="<b>" . $monthString . "</b><br />";
                                $newsmonth=$month;
                                }
                            $t.="<img src=\"" . $plugin_images_folder . "news_item.gif"
                                . "\" alt=\"calendar_img\"></img>&nbsp;"
                                . date($plugin_tx[$plugin]['news_date_format'], $field[NEWS_DATE])
                                . "&nbsp;&nbsp;&nbsp;<a href=\"" . $sn . "?" . $u[$s] . "&amp;newsaction=view&amp;newsID=" . $field[NEWS_ID] . "&amp;page=" . $page . "\" title=\"" . $plugin_tx[$plugin]["news_tooltip_view"] . "\" >" . $field[NEWS_TITLE] . "</a><br />";
                            }
                        }
                    else { $t.=$plugin_tx[$plugin]['news_no_topics']; }
                    }

                break;
            }
        }
    else
        {
        // Display the newsitem for the given ID
        $record=$db->selectUnique($db_name, NEWS_ID, $newsID);

        // Set the return page, based on the caling page
        if ($from_page == '' || empty($from_page)) { $from_page=1; }

        $return_page=($from_page == $u[$s]) ? $u[$s] : $from_page;

        if (count($record) > 0)
            {
            // Show selected news details
            $t.="<div class=\"show_news_box\">";
            $t.="<div>&nbsp;</div>";
            $t.="<div class=\"show_news_title\">" . $record[NEWS_TITLE] . "</div>";
            $t.="<div class=\"show_news_date\">"
                . strftime($plugin_tx[$plugin]['news_display_date_format'], $record[NEWS_DATE]) . "</div>";
            $t.="<div class=\"show_news_story\">" . stripslashes($record[NEWS_STORY]) . "</div>";
            $t.="</div>";
            $t.="<div>&nbsp;</div>";
            $t.="<div>&nbsp;</div>";

            if (isset($printnews))
                {
                $tt="<html><head><title>" . sitename() . " - " . str_replace('_', ' ', $u[$s]) . "</title>";
                $tt.="<link rel='stylesheet' href='" . $pth['folder']['plugins'] . $plugin
                    . "/css/stylesheet.css' type='text/css'>";
                $tt.="</head><body>";
                $tt.=$t;
                $tt.="<div align=\"center\"><a href=javascript:void(0); onclick='window.close()'>"
                    . $plugin_tx[$plugin][window_close] . "</a>&nbsp;&nbsp;&nbsp;<a href=javascript:void(0); onclick='window.print()'>" . $plugin_tx[$plugin][window_print] . "</a></div>";
                $tt.='</body></html>';
                $t.="<script language='javascript' type='text/javascript'>
                var printinfo = '" . addslashes($tt)
                    . "';
                win = window.open('', 'printversion', 'toolbar = 0, status = 0, width=600',scrollbars=1);
                win.document.write(printinfo);
                win.document.close();
                </script>";
                }

            // Redirect back to last visited page
            $t.="<div><form name=\"confirm\" method=\"post\" action=\"" . $sn . "?" . $return_page . "\">";
            //$pdfprinter=function_exists('pdflink')?"&nbsp;&nbsp;&nbsp;<input type=\"button\" name=\"pdfprint\" value=\"&nbsp;".$tx['menu']['pdf']."&nbsp;\" onclick='location.href=\"".$sn."?".$u[$s]."&newsaction=view&newsID=".$newsID."&pdf\"'>":"";
            $t.="<div class=\"confirm_button\" align=\"center\"><input type=\"button\" name=\"cancel\" value=\"&nbsp;"
                . $plugin_tx[$plugin]['news_btn_back'] . "&nbsp;\" onclick='location.href=\"" . $sn . "?" . $u[$s] . "&page=" . $_SESSION['page'] . "&amp;newsYear=" . $_SESSION['newsYear'] . "\"' />&nbsp;&nbsp;&nbsp;<input type=\"button\" name=\"print\" value=\"&nbsp;" . $tx['menu']['print'] . "&nbsp;\" onclick='location.href=\"" . $sn . "?" . $u[$s] . "&amp;newsaction=view&amp;newsID=" . $newsID . "&amp;printnews\" '/>" . $pdfprinter . "</div>";
            $t.="</div></form>";
            }
        }

    if ($newsaction == 'search' && !isset($printnews)) { $t
        .="<br /><br /><form><table width=\"100%\"><tr><td align=\"center\"><input type=\"button\" name=\"return\" value=\""
        . $plugin_tx[$plugin]['news_return'] . "\" onclick='location.href=\"" . $sn . "?" . $u[$s] . "\" '/></td></tr></table></form>";
        }
$c[$s]="";
    unset ($newsaction);
    unset ($compClause);
    return ($t);
    }

/*
********************************************************************************
* This function display's the news topics from within the template with a link to
* the newsbox page and is used to be called from the CMSimple template.
* pre-conditions : a page including the script #cmsimple $output.=shownewsbox();#
*                  must be present, otherwise the news item details won't be displayed.
* parameters :
*     - news_page [required] : this is the page containing the
*                              shownewsbox() function
*     - alwayspublish [optional] : on/off ; includes news topics marked
*                              with 'on frontpage'
********************************************************************************
*/

function advancednewslink ($options)
    {
    global $pth, $sn, $plugin_tx, $plugin_cf, $u, $s, $c, $h, $sl;
    $includeonfrontpage='false';
    $arguments         =split(",", $options);
global $from_page;
$from_page=$u[$s];
    if (count($arguments > 0))
        {
        foreach ($arguments as $argument)
            {
            $property = split("=", $argument);

            switch (strtolower($property[0]))
                {
                case "newspage":
                    $news_page=$property[1];

                    break;

                case "alwayspublish":
                    if (strtolower($property[1]) === "true" || strtolower($property[1]) === "false"
                        || strtolower($property[1]) === "1" || strtolower($property[1]) === "0")
                        {
                        switch ($property[1])
                            {
                            case '0':
                                $includeonfrontpage='false';

                                break;

                            case '1':
                                $includeonfrontpage='true';

                                break;

                            default:
                                $includeonfrontpage=$property[1];

                                break;
                            }
                        }
                    else { $includeonfrontpage='false'; }

                    break;
                }
            }
        }

    // Check if the specified news_page realy exists
    $page_exists=false;

    foreach ($u as $key => $value)
        {
        if ($news_page === $value)
            {
            if ($s == $key)
                {
                $page_exists=true;
                break;
                }

            if (preg_match("/shownewsbox\(.*/is", $c[$key]))
                {
                $page_exists=true;
                break;
                }
            }
        }

    if (!$page_exists) { return (""); }

    if (!empty($news_page) || $news_page != '')
        {
        //        print_r($_SESSION);
        // Register the current page in a session variable
        $plugin=basename(dirname(__FILE__), "/");
        // set general variables for the plugin
        $plugin_images_folder=$pth['folder']['plugins'] . $plugin . "/images/";
        $plugin_include_folder=$pth['folder']['plugins'] . $plugin . "/include/";
        setlocale(LC_ALL, $plugin_tx[$plugin]['news_date_locale']);
        $db_path=$pth['folder']['plugins'] . $plugin . "/data/";
        $db_name="news-" . $sl . ".txt";
        // include the flatfile database class
        require_once ($plugin_include_folder . "flatfile.php");
        // declare the news database fields
        require_once ($plugin_include_folder . "fields.php");
        // connect to the news database file
        $db=new Flatfile();
        $db->datadir=$db_path;

        if ($id == -1 || empty($id) || !isset($id))
            {
            // Select all published news items ordered by DATE descending within the publishing range
            $d         =date("d", time());
            $m         =date("n", time());
            $y         =date("Y", time());
            $today     =mktime(NULL, NULL, NULL, $m, $d, $y);
            $compClause=NULL;
            $compClause=new AndWhereClause(new SimpleWhereClause(NEWS_STATUS, "=", 1, INTEGER_COMPARISON),
                                           new AndWhereClause(
                                               new SimpleWhereClause(NEWS_STARTDATE, "<=", $today, INTEGER_COMPARISON),
                                               new SimpleWhereClause(NEWS_ENDDATE, ">=", $today, INTEGER_COMPARISON)));

            if (strtolower($includeonfrontpage) === 'true') { $compClause
                =new OrWhereClause(new SimpleWhereClause(NEWS_FRONTPAGE, "=", 'on', STRING_COMPARISON),
                                       $compClause); }

            $newslist    =$db->selectWhere($db_name, $compClause, -1, array
                (
                new OrderBy(NEWS_DATE, DESCENDING, INTEGER_COMPARISON),
                new OrderBy(NEWS_ID, DESCENDING, INTEGER_COMPARISON)
                ));

            // Show the results
            $max_visible =$plugin_cf[$plugin]['news_items_visible'];
            $news_counter=0;

            if (count($newslist) > 0)
                {
                if ($max_visible <= 0 || empty($max_visible)) { $max_visible=count($newslist); }
                $t.="<div class=\"tpl_show_news_box\">";
                foreach ($newslist as $index => $record)
                    {
                    $news_counter++;
                    $t.="<div class=\"tpl_show_news_title\"><a href=\"" . $sn . "?" . $news_page . "&amp;id="
                        . $record[NEWS_ID] . "&amp;from_page=" . $u[$s] . "\" title=\"" . $plugin_tx[$plugin]['news_tooltip_view'] . "\" >" . $record[NEWS_TITLE] .'</a></div>';
                    $t.="<div class=\"tpl_show_news_date\">".strftime($plugin_tx[$plugin]['news_display_date_format'], $record[NEWS_DATE]) . "</div>";

                    // Limit the number of visible news items (set in the configuration; empty=all news)
                    if ($plugin_cf[$plugin]['news_items_visible'] > 0)
                        {
                        if ($news_counter == $max_visible) { break; }
                        }
                    }
                }
            else { $t.=''.$plugin_tx[$plugin]['news_no_topics'].''; }
            }
        }
    else { $t=''; }
    $t.='</div>';
    return ($t);
    }

/*
********************************************************************************
* This function display's the latest (x) news topics
* parameters :
*     - id [interger | optional]
*       => the news item id you want to display
*     - alwayspublish [boolean | optional] : true/false or 1/0
*       => include news items marked as 'always publish' (independant of the
*          publishing date)
*     - showlatest [integer | optional]
*       => overrules the latest x news items to display set in the plugin config
*          module
********************************************************************************
*/

function shownewsbox ($options = NULL)
    {
    global $tx, $pth, $sn, $plugin_tx, $plugin_cf, $u, $s, $c, $sl;
    global $from_page;
    $id                =-1;
    $includeonfrontpage='false';
    $limit             =NULL;
    $id                =isset($_POST['id']) ? $_POST['id'] : $_GET['id'];
    $printnews         =isset($_POST['printnews']) ? $_POST['printnews'] : $_GET['printnews'];
    $from_page         =$_REQUEST['from_page'];
    $plugin            =basename(dirname(__FILE__), "/");
    $arguments         =split(",", $options);

    if (count($arguments > 0))
        {
        foreach ($arguments as $argument)
            {
            $property = split("=", $argument);

            switch (strtolower($property[0]))
                {
                case "id":
                    $id=strtolower($property[1]);

                    break;

                case "alwayspublish":
                    if (strtolower($property[1]) === "true" || strtolower($property[1]) === "false"
                        || strtolower($property[1]) === "1" || strtolower($property[1]) === "0")
                        {
                        switch ($property[1])
                            {
                            case '0':
                                $includeonfrontpage='false';

                                break;

                            case '1':
                                $includeonfrontpage='true';

                                break;

                            default:
                                $includeonfrontpage=$property[1];

                                break;
                            }
                        }
                    else { $includeonfrontpage='false'; }

                    break;

                case "showlatest":
                    $limit=0;

                    $limit=$property[1];

                    if ($property[1] > 0) { $limit=$property[1]; }
                    else { $limit=$plugin_cf[$plugin]['news_items_visible']; }

                    break;
                }
            }
        }

    // set general variables for the plugin
    $plugin_images_folder=$pth['folder']['plugins'] . $plugin . "/images/";
    $plugin_include_folder=$pth['folder']['plugins'] . $plugin . "/include/";
    setlocale(LC_ALL, $plugin_tx[$plugin]['news_date_locale']);
    $db_path=$pth['folder']['plugins'] . $plugin . "/data/";
    $db_name="news-" . $sl . ".txt";
    // declare the news database fields
    require_once ($plugin_include_folder . "fields.php");
    // include the flatfile database class
    require_once ($plugin_include_folder . "flatfile.php");
    // connect to the news database file
    $db=new Flatfile();
    $db->datadir=$db_path;

    if ($id == -1 || empty($id) || !isset($id))
        {
        // Select all published news items ordered by DATE descending within the publishing range
        $d         =date("d", time());
        $m         =date("n", time());
        $y         =date("Y", time());
        $today     =mktime(NULL, NULL, NULL, $m, $d, $y);
        $compClause=NULL;
        $compClause=new AndWhereClause(new SimpleWhereClause(NEWS_STATUS, "=", 1, INTEGER_COMPARISON),
                                       new AndWhereClause(
                                           new SimpleWhereClause(NEWS_STARTDATE, "<=", $today, INTEGER_COMPARISON),
                                           new SimpleWhereClause(NEWS_ENDDATE, ">=", $today, INTEGER_COMPARISON)));

        if (strtolower($includeonfrontpage) === 'true')
            { $compClause=new OrWhereClause(new SimpleWhereClause(NEWS_FRONTPAGE, "=", 'on', STRING_COMPARISON),
                                                $compClause); }

        $newslist=$db->selectWhere($db_name, $compClause, -1,array
                (
                new OrderBy(NEWS_DATE, DESCENDING, INTEGER_COMPARISON),
                new OrderBy(NEWS_ID, DESCENDING, INTEGER_COMPARISON)
                ));

        // Show the results
        if (!is_numeric($limit)) { $limit=$plugin_cf[$plugin]['news_items_visible']; }

        $max_visible=($limit > 0) ? $limit : $plugin_cf[$plugin]['news_items_visible'];
        $news_counter=0;

        if (count($newslist) > 0)
            {
            foreach ($newslist as $index => $record)
                {
                $news_counter++;
                $t.="<div class=\"show_news_box\">";
                $t.="<div class=\"show_news_title\"><a href=\"" . $sn . "?" . $u[$s] . "&amp;id=" . $record[NEWS_ID]
                    . "\" title=\"" . $plugin_tx[$plugin]['news_tooltip_view'] . "\" >" . $record[NEWS_TITLE] . "</a></div>";
                $t.="<div class=\"show_news_date\">"
                    . strftime($plugin_tx[$plugin]['news_display_date_format'], $record[NEWS_DATE]) . "</div>";
                $t.="<div class=\"show_news_story\">" . $record[NEWS_HEADLINE] . "&nbsp;<a href=\"" . $sn . "?" . $u[$s]
                    . "&amp;id=" . $record[NEWS_ID] . "\" title=\"" . $plugin_tx[$plugin]['news_tooltip_view'] . "\">" . $plugin_tx[$plugin]['news_read_more'] . "</a></div>";
                $t.="</div>";

                // Limit the number of visible news topics (set in the configuration; empty=display all news topics)
                if ($plugin_cf[$plugin]['news_items_visible'] > 0)
                    {
                    if ($news_counter == $max_visible) { break; }
                    }
                }
            }
        else { $t.=$plugin_tx[$plugin]['news_no_topics']; }

        //$t=preg_replace($cf['scripting']['regexp'], $t, $c[$s]);
        }
    else
        {
        // Select the newsitem for the given ID
        $record=$db->selectUnique($db_name, NEWS_ID, $id);

        // Set the return page, based on the caling page
        if ($from_page == '' || empty($from_page)) { $from_page=$u[$s]; }

        $return_page=($from_page == $u[$s]) ? $u[$s] : $from_page;

        if (count($record) > 0)
            {
            // Show selected news details
            $t.="<div class=\"show_news_box\">";
            $t.="<div>&nbsp;</div>";
            $t.="<div class=\"show_news_title\">" . $record[NEWS_TITLE] . "</div>";
            $t.="<div class=\"show_news_date\">"
                . strftime($plugin_tx[$plugin]['news_display_date_format'], $record[NEWS_DATE]) . "</div>";
            $t.="<div class=\"show_news_story\">" . stripslashes($record[NEWS_STORY]) . "</div>";
            $t.="</div>";
            $t.="<div>&nbsp;</div>";
            $t.="<div>&nbsp;</div>";

            if (isset($printnews))
                {
                $tt="<html><head><title>" . sitename() . " - " . str_replace('_', ' ', $u[$s]) . "</title>";
                $tt.="<link rel='stylesheet' href='" . $pth['folder']['plugins'] . $plugin
                    . "/css/stylesheet.css' type='text/css'>";
                $tt.="</head><body>";
                $tt.=$t;
                $tt.="<div align=\"center\"><a href=javascript:void(0); onclick='window.close()'>"
                    . $plugin_tx[$plugin][window_close] . "</a>&nbsp;&nbsp;&nbsp;<a href=javascript:void(0); onclick='window.print()'>" . $plugin_tx[$plugin][window_print] . "</a></div>";
                $tt.='</body></html>';
                $t.="<script language='javascript' type='text/javascript'>
                var printinfo = '" . addslashes($tt)
                    . "';
                win = window.open('', 'printversion', 'toolbar = 0, status = 0, width=600,scrollbars=1');
                win.document.write(printinfo);
                win.document.close();
                </script>";
                }

            // Redirect back to news overview
            $t.="<div><form name=\"confirm\" method=\"post\" action=\"" . $sn . "?" . $return_page . "\">";

            //$pdfprinter=function_exists('pdflink')?"&nbsp;&nbsp;&nbsp;<input type=\"button\" name=\"pdfprint\" value=\"&nbsp;".$tx['menu']['pdf']."&nbsp;\" onclick='location.href=\"".$sn."?".$u[$s]."&id=".$id."&pdf\"'>":"";
            if ($_SESSION['page'] != '') { $t
                .="<div class=\"confirm_button\" align=\"center\"><input type=\"button\" name=\"cancel\" value=\"&nbsp;"
                . $plugin_tx[$plugin]['news_btn_back'] . "&nbsp;\" onclick='location.href=\"" . $sn . "?" . $u[$s] . "&amp;page="
                . $_SESSION['page'] . "&amp;newsYear=" . $_SESSION['newsYear'] . "\"' />";
				if(strtolower($plugin_cf[$plugin]['news_enable_printbutton'])=="true"){
				$t.="&nbsp;&nbsp;&nbsp;<input type=\"button\" name=\"print\" value=\"&nbsp;"
                . $tx['menu']['print'] . "&nbsp;\" onclick='location.href=\"" . $sn . "?" . $u[$s] . "&amp;id=" . $id
                . "&amp;printnews\"' />" . $pdfprinter;} 
				$t.= "</div>"; }

            if ($_SESSION['page'] == '') { $t
                .="<div class=\"confirm_button\" align=\"center\"><input type=\"button\" name=\"cancel\" value=\"&nbsp;"
                . $plugin_tx[$plugin]['news_btn_back'] . "&nbsp;\" onclick='location.href=\"" . $sn . "?" . $return_page
                . "\"'/>";
				if(strtolower($plugin_cf[$plugin]['news_enable_printbutton'])=="true"){
				$t.="&nbsp;&nbsp;&nbsp;<input type=\"button\" name=\"print\" value=\"&nbsp;" . $tx['menu']['print']
                . "&nbsp;\" onclick='location.href=\"" . $sn . "?" . $u[$s] . "&amp;id=" . $id . "&amp;printnews\"' />"         . $pdfprinter ;}
			$t.="</div>"; }
            $t.="</div></form>";
			}
        else
            {
            header ("Location:" . $sn . "?" . $return_page);
            exit;
            }
        } 
    	return ($t);
    }

/*
********************************************************************************
* This internal function makes a timestamp date from a give date
* parameters :
*     - tmpdate [optional] : date to be converted to a timestamp (if omitted, the
*                            current date is used)
* The function also generates some internal settings, used in the datepicker.js
* function.
********************************************************************************
*/

function make_timestamp_date1 ($tmpdate = null)
    {
    global $plugin_cf, $plugin_tx;
    // get plugin name
    $plugin        =basename(dirname(__FILE__), "/");
    $my_date_format=split('[/]', $plugin_tx[$plugin]['news_date_format']);

    if (count($my_date_format) > 1) { $date_separator="/"; }
    else
        {
        $my_date_format=split('[.]', $plugin_tx[$plugin]['news_date_format']);

        if (count($my_date_format) > 1) { $date_separator="."; }
        else
            {
            $my_date_format=split('[-]', $plugin_tx[$plugin]['news_date_format']);

            if (count($my_date_format) > 1) { $date_separator="-"; }
            }
        }

    for ($aCounter=0; $aCounter <= 2; $aCounter++)
        {
        switch ($my_date_format[$aCounter])
            {
            case 'd':
                $dayposition                          =$aCounter;

                $my_detected_date_format[$dayposition]=$my_date_format[$aCounter];
                $cal_date_format[$dayposition]        ="DD";
                $regex[$dayhposition]                 ='([0-9]{1,2})';
                break;

            case 'm':
                $monthposition                          =$aCounter;

                $my_detected_date_format[$monthposition]=$my_date_format[$aCounter];
                $cal_date_format[$monthposition]        ="MM";
                $regex[$monthposition]                  ='([0-9]{1,2})';
                break;

            case 'y':
                $yearposition                          =$aCounter;

                $my_detected_date_format[$yearposition]=$my_date_format[$aCounter];
                $cal_date_format[$yearposition]        ="YY";
                $regex[$yearposition]                  ='([0-9]{2})';
                break;

            case 'Y':
                $yearposition                          =$aCounter;

                $my_detected_date_format[$yearposition]=$my_date_format[$aCounter];
                $cal_date_format[$yearposition]        ="YYYY";
                $regex[$yearposition]                  ='([0-9]{4})';
                break;
            }
        }

    foreach ($my_detected_date_format as $key => $value)
        {
        if ($key < (count($my_detected_date_format) - 1)) { $date_format.=$value . $date_separator; }
        else { $date_format.=$value; }
        }

    foreach ($cal_date_format as $key => $value) { $cal_format.=$value; }

    foreach ($regex as $key => $value)
        {
        if ($key < (count($regex) - 1)) { $regex_format.=$value . $date_separator; }
        else { $regex_format.=$value; }
        }

    if ($tmpdate == null) { $tmpdate=date($plugin_tx[$plugin]['news_date_format'], time()); }

    if (ereg($regex_format, $tmpdate))
        {
        $dateArr=split('[-,/,.]', $tmpdate);
        $m      =$dateArr[$monthposition];
        $d      =$dateArr[$dayposition];
        $y      =$dateArr[$yearposition];
        }

    $tmpdate=mktime(null, null, null, $m, $d, $y);
    return ($tmpdate);
    }

/*
********************************************************************************
* This function makes a rss compatible newsfeed file
* parameters : none
********************************************************************************
*/

function export_rssfeed ()
    {
    global $tx, $pth, $sn, $u, $s, $c, $sl, $plugin_cf, $plugin_tx;
    $plugin=basename(dirname(__FILE__), "/");
    // set general variables for the plugin
    include_once ($pth['folder']['plugins'] . $plugin . "/config/config.php");
    include_once ($pth['folder']['plugins'] . $plugin . "/languages/" . $sl . ".php");

    if (strtolower($plugin_tx[$plugin]['news_rss_enable']) == 'true')
        {
        $plugin_images_folder=$pth['folder']['plugins'] . $plugin . "/images/";
        $plugin_include_folder=$pth['folder']['plugins'] . $plugin . "/include/";
        $rss_path=$pth['folder']['plugins'] . $plugin . "/rss/";
        //setlocale(LC_ALL,$plugin_tx[$plugin]['news_date_locale']);
        $db_path=$pth['folder']['plugins'] . $plugin . "/data/";
        $db_name="news-" . $sl . ".txt";
        // declare the news database fields
        require_once ($plugin_include_folder . "fields.php");
        // include the flatfile database class
        require_once ($plugin_include_folder . "flatfile.php");
        // connect to the news database file
        $db=new Flatfile();
        $db->datadir=$db_path;

        if (!$fp=@fopen($rss_path . "newsfeed-" . $sl . ".xml", "w+")) { echo ("Unable to write to outputfile"); }
        else
            {
            fputs($fp, "<?xml version=\"1.0\" encoding=\"" . strtolower($plugin_cf[$plugin]['news_rss_encoding'])
                      . "\"?>\n");
            fputs($fp,
                  "<rss version=\"2.0\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:sy=\"http://purl.org/rss/1.0/modules/syndication/\" xmlns:admin=\"http://webns.net/mvcb/\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:content=\"http://purl.org/rss/1.0/modules/content/\">\n");
            fputs($fp, "<channel>\n");
            fputs($fp, "<title>" . $plugin_tx[$plugin]['news_rss_title'] . "</title>\n");
            fputs($fp, "<link>" . $plugin_cf[$plugin]['news_rss_link'] . "</link>\n");
            fputs($fp, "<description>" . $plugin_tx[$plugin]['news_rss_description'] . "</description>\n");
            fputs($fp, "<language>" . $plugin_tx[$plugin]['news_rss_language'] . "</language>\n");
            fputs($fp, "<copyright>" . $plugin_cf[$plugin]['news_rss_copyright'] . "</copyright>\n");
            fputs($fp, "<managingEditor>" . $plugin_cf[$plugin]['news_rss_editor'] . "</managingEditor>\n");
            fputs($fp, "<image>\n");
            fputs($fp, "<title>" . $plugin_tx[$plugin]['news_rss_title'] . "</title>\n");
            fputs($fp, "<url>" . $plugin_cf[$plugin]['news_rss_logo'] . "</url>\n");
            fputs($fp, "<link>" . $plugin_cf[$plugin]['news_rss_link'] . "</link>\n");
            fputs($fp, "<width>65</width>\n");
            fputs($fp, "<height>35</height>\n");
            fputs($fp, "<description>" . $plugin_tx[$plugin]['news_rss_descr'] . "</description>\n");
            fputs($fp, "</image>\n");
            $compClause=new SimpleWhereClause(NEWS_RSSFEED, "=", "on", STRING_COMPARISON);
            $newslist  =$db->selectWhere($db_name, $compClause, -1,array
                (
                new OrderBy(NEWS_DATE, DESCENDING, INTEGER_COMPARISON),
                new OrderBy(NEWS_ID, DESCENDING, INTEGER_COMPARISON)
                ));

            // Show the RSS news items
            if (count($newslist) > 0)
                {
                foreach ($newslist as $index => $record)
                    {
                    fputs($fp, "<item>\n");
                    $title="<title>" . htmlspecialchars(stripslashes($record[NEWS_TITLE])) . "</title>\n";
                    $link="<link>" . $plugin_cf[$plugin]["news_rss_link"] . "/?" . $plugin_tx[$plugin]["news_rss_page"]
                        . "&amp;id=" . $record[NEWS_ID] . "</link>\n";
                    $description="<description>" . htmlspecialchars(stripslashes($record[NEWS_HEADLINE]))
                        . "</description>\n";
                    $pubDate="<pubDate>" . strftime("%a, %d %b %Y", $record[NEWS_DATE]) . " 00:00:00 GMT</pubDate>\n";
                    fputs($fp, $title);
                    fputs($fp, $link);
                    fputs($fp, $description);
                    fputs($fp, $pubDate);
                    fputs($fp, "</item>\n");
                    }
                }

            fputs($fp, "</channel>\n");
            fputs($fp, "</rss>\n");
            fclose ($fp);
            }
        }
    }

/*
********************************************************************************
* This function displays a graphical hyperlink to the newsfeed file
* parameters :
*   - replace [optional]    : true/false or 1/0
*                             when set to true, the scripting line will be
*                             replaced with the content generated by the function
********************************************************************************
*/

function rss_advertise ($options = NULL)
    {
    global $plugin_tx, $plugin_cf, $pth, $sl, $c, $s;
    $plugin              =basename(dirname(__FILE__), "/");
    $plugin_images_folder=$pth['folder']['plugins'] . $plugin . "/images/";
    $rss_path            =$pth['folder']['plugins'] . $plugin . "/rss/";
    $option_replace      ='false';
    // determine the function arguments (separated by a comma)
    $arguments           =split(",", $options);

    if (count($arguments > 0))
        {
        foreach ($arguments as $argument)
            {
            $property = split("=", $argument);

            switch ($property[0])
                {
                case "replace":
                    if (strtolower($property[1]) == "true" || strtolower($property[1]) == "false"
                        || strtolower($property[1]) == 1 || strtolower($property[1]) == 0)
                        { $option_replace=strtolower($property[1]); }

                    break;
                }
            }
        }
    else { $option_replace='false'; }

    $tt='';
    $tt="<br /><a href=\"" . $rss_path . "newsfeed-" . $sl . ".xml\"><img src=\"" . $plugin_images_folder
        . "rss.gif\" width=\"36\" height=\"14\" alt=\"" . $plugin_tx[$plugin]['news_rss_tooltip'] . "\" border=\"0\" /></a>";

    if ($option_replace === is_bool('true'))
        { $tt=preg_replace("/" .$cf['scripting']['regexp']. "/is", $tt, $c[$s]); }

    return ($tt);
    }
?>